mocks

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 16, 2025 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MarketMapHooks

type MarketMapHooks struct {
	mock.Mock
}

MarketMapHooks is an autogenerated mock type for the MarketMapHooks type

func NewMarketMapHooks

func NewMarketMapHooks(t interface {
	mock.TestingT
	Cleanup(func())
}) *MarketMapHooks

NewMarketMapHooks creates a new instance of MarketMapHooks. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MarketMapHooks) AfterMarketCreated

func (_m *MarketMapHooks) AfterMarketCreated(ctx types.Context, market marketmaptypes.Market) error

AfterMarketCreated provides a mock function with given fields: ctx, market

func (*MarketMapHooks) AfterMarketGenesis

func (_m *MarketMapHooks) AfterMarketGenesis(ctx types.Context, tickers map[string]marketmaptypes.Market) error

AfterMarketGenesis provides a mock function with given fields: ctx, tickers

func (*MarketMapHooks) AfterMarketRemoved

func (_m *MarketMapHooks) AfterMarketRemoved(ctx types.Context, key string) error

AfterMarketRemoved provides a mock function with given fields: ctx, key

func (*MarketMapHooks) AfterMarketUpdated

func (_m *MarketMapHooks) AfterMarketUpdated(ctx types.Context, market marketmaptypes.Market) error

AfterMarketUpdated provides a mock function with given fields: ctx, market

type QueryClient

type QueryClient struct {
	mock.Mock
}

QueryClient is an autogenerated mock type for the QueryClient type

func NewQueryClient

func NewQueryClient(t interface {
	mock.TestingT
	Cleanup(func())
}) *QueryClient

NewQueryClient creates a new instance of QueryClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*QueryClient) EXPECT

func (_m *QueryClient) EXPECT() *QueryClient_Expecter

func (*QueryClient) LastUpdated

LastUpdated provides a mock function with given fields: ctx, in, opts

func (*QueryClient) Market

Market provides a mock function with given fields: ctx, in, opts

func (*QueryClient) MarketMap

MarketMap provides a mock function with given fields: ctx, in, opts

func (*QueryClient) Markets

Markets provides a mock function with given fields: ctx, in, opts

func (*QueryClient) Params

Params provides a mock function with given fields: ctx, in, opts

type QueryClient_Expecter

type QueryClient_Expecter struct {
	// contains filtered or unexported fields
}

func (*QueryClient_Expecter) LastUpdated

func (_e *QueryClient_Expecter) LastUpdated(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_LastUpdated_Call

LastUpdated is a helper method to define mock.On call

  • ctx context.Context
  • in *types.LastUpdatedRequest
  • opts ...grpc.CallOption

func (*QueryClient_Expecter) Market

func (_e *QueryClient_Expecter) Market(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_Market_Call

Market is a helper method to define mock.On call

  • ctx context.Context
  • in *types.MarketRequest
  • opts ...grpc.CallOption

func (*QueryClient_Expecter) MarketMap

func (_e *QueryClient_Expecter) MarketMap(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_MarketMap_Call

MarketMap is a helper method to define mock.On call

  • ctx context.Context
  • in *types.MarketMapRequest
  • opts ...grpc.CallOption

func (*QueryClient_Expecter) Markets

func (_e *QueryClient_Expecter) Markets(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_Markets_Call

Markets is a helper method to define mock.On call

  • ctx context.Context
  • in *types.MarketsRequest
  • opts ...grpc.CallOption

func (*QueryClient_Expecter) Params

func (_e *QueryClient_Expecter) Params(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_Params_Call

Params is a helper method to define mock.On call

  • ctx context.Context
  • in *types.ParamsRequest
  • opts ...grpc.CallOption

type QueryClient_LastUpdated_Call

type QueryClient_LastUpdated_Call struct {
	*mock.Call
}

QueryClient_LastUpdated_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'LastUpdated'

func (*QueryClient_LastUpdated_Call) Return

func (*QueryClient_LastUpdated_Call) Run

type QueryClient_MarketMap_Call

type QueryClient_MarketMap_Call struct {
	*mock.Call
}

QueryClient_MarketMap_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'MarketMap'

func (*QueryClient_MarketMap_Call) Return

func (*QueryClient_MarketMap_Call) Run

func (*QueryClient_MarketMap_Call) RunAndReturn

type QueryClient_Market_Call

type QueryClient_Market_Call struct {
	*mock.Call
}

QueryClient_Market_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Market'

func (*QueryClient_Market_Call) Return

func (*QueryClient_Market_Call) Run

func (*QueryClient_Market_Call) RunAndReturn

type QueryClient_Markets_Call

type QueryClient_Markets_Call struct {
	*mock.Call
}

QueryClient_Markets_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Markets'

func (*QueryClient_Markets_Call) Return

func (*QueryClient_Markets_Call) Run

func (*QueryClient_Markets_Call) RunAndReturn

type QueryClient_Params_Call

type QueryClient_Params_Call struct {
	*mock.Call
}

QueryClient_Params_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Params'

func (*QueryClient_Params_Call) Return

func (*QueryClient_Params_Call) Run

func (*QueryClient_Params_Call) RunAndReturn

Jump to