Documentation
¶
Index ¶
- type MarketMapHooks
- func (_m *MarketMapHooks) AfterMarketCreated(ctx types.Context, market marketmaptypes.Market) error
- func (_m *MarketMapHooks) AfterMarketGenesis(ctx types.Context, tickers map[string]marketmaptypes.Market) error
- func (_m *MarketMapHooks) AfterMarketRemoved(ctx types.Context, key string) error
- func (_m *MarketMapHooks) AfterMarketUpdated(ctx types.Context, market marketmaptypes.Market) error
- type QueryClient
- func (_m *QueryClient) EXPECT() *QueryClient_Expecter
- func (_m *QueryClient) LastUpdated(ctx context.Context, in *types.LastUpdatedRequest, opts ...grpc.CallOption) (*types.LastUpdatedResponse, error)
- func (_m *QueryClient) Market(ctx context.Context, in *types.MarketRequest, opts ...grpc.CallOption) (*types.MarketResponse, error)
- func (_m *QueryClient) MarketMap(ctx context.Context, in *types.MarketMapRequest, opts ...grpc.CallOption) (*types.MarketMapResponse, error)
- func (_m *QueryClient) Markets(ctx context.Context, in *types.MarketsRequest, opts ...grpc.CallOption) (*types.MarketsResponse, error)
- func (_m *QueryClient) Params(ctx context.Context, in *types.ParamsRequest, opts ...grpc.CallOption) (*types.ParamsResponse, error)
- type QueryClient_Expecter
- func (_e *QueryClient_Expecter) LastUpdated(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_LastUpdated_Call
- func (_e *QueryClient_Expecter) Market(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_Market_Call
- func (_e *QueryClient_Expecter) MarketMap(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_MarketMap_Call
- func (_e *QueryClient_Expecter) Markets(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_Markets_Call
- func (_e *QueryClient_Expecter) Params(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_Params_Call
- type QueryClient_LastUpdated_Call
- type QueryClient_MarketMap_Call
- type QueryClient_Market_Call
- type QueryClient_Markets_Call
- type QueryClient_Params_Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MarketMapHooks ¶
MarketMapHooks is an autogenerated mock type for the MarketMapHooks type
func NewMarketMapHooks ¶
func NewMarketMapHooks(t interface {
mock.TestingT
Cleanup(func())
}) *MarketMapHooks
NewMarketMapHooks creates a new instance of MarketMapHooks. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*MarketMapHooks) AfterMarketCreated ¶
func (_m *MarketMapHooks) AfterMarketCreated(ctx types.Context, market marketmaptypes.Market) error
AfterMarketCreated provides a mock function with given fields: ctx, market
func (*MarketMapHooks) AfterMarketGenesis ¶
func (_m *MarketMapHooks) AfterMarketGenesis(ctx types.Context, tickers map[string]marketmaptypes.Market) error
AfterMarketGenesis provides a mock function with given fields: ctx, tickers
func (*MarketMapHooks) AfterMarketRemoved ¶
func (_m *MarketMapHooks) AfterMarketRemoved(ctx types.Context, key string) error
AfterMarketRemoved provides a mock function with given fields: ctx, key
func (*MarketMapHooks) AfterMarketUpdated ¶
func (_m *MarketMapHooks) AfterMarketUpdated(ctx types.Context, market marketmaptypes.Market) error
AfterMarketUpdated provides a mock function with given fields: ctx, market
type QueryClient ¶
QueryClient is an autogenerated mock type for the QueryClient type
func NewQueryClient ¶
func NewQueryClient(t interface {
mock.TestingT
Cleanup(func())
}) *QueryClient
NewQueryClient creates a new instance of QueryClient. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*QueryClient) EXPECT ¶
func (_m *QueryClient) EXPECT() *QueryClient_Expecter
func (*QueryClient) LastUpdated ¶
func (_m *QueryClient) LastUpdated(ctx context.Context, in *types.LastUpdatedRequest, opts ...grpc.CallOption) (*types.LastUpdatedResponse, error)
LastUpdated provides a mock function with given fields: ctx, in, opts
func (*QueryClient) Market ¶
func (_m *QueryClient) Market(ctx context.Context, in *types.MarketRequest, opts ...grpc.CallOption) (*types.MarketResponse, error)
Market provides a mock function with given fields: ctx, in, opts
func (*QueryClient) MarketMap ¶
func (_m *QueryClient) MarketMap(ctx context.Context, in *types.MarketMapRequest, opts ...grpc.CallOption) (*types.MarketMapResponse, error)
MarketMap provides a mock function with given fields: ctx, in, opts
func (*QueryClient) Markets ¶
func (_m *QueryClient) Markets(ctx context.Context, in *types.MarketsRequest, opts ...grpc.CallOption) (*types.MarketsResponse, error)
Markets provides a mock function with given fields: ctx, in, opts
func (*QueryClient) Params ¶
func (_m *QueryClient) Params(ctx context.Context, in *types.ParamsRequest, opts ...grpc.CallOption) (*types.ParamsResponse, error)
Params provides a mock function with given fields: ctx, in, opts
type QueryClient_Expecter ¶
type QueryClient_Expecter struct {
// contains filtered or unexported fields
}
func (*QueryClient_Expecter) LastUpdated ¶
func (_e *QueryClient_Expecter) LastUpdated(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_LastUpdated_Call
LastUpdated is a helper method to define mock.On call
- ctx context.Context
- in *types.LastUpdatedRequest
- opts ...grpc.CallOption
func (*QueryClient_Expecter) Market ¶
func (_e *QueryClient_Expecter) Market(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_Market_Call
Market is a helper method to define mock.On call
- ctx context.Context
- in *types.MarketRequest
- opts ...grpc.CallOption
func (*QueryClient_Expecter) MarketMap ¶
func (_e *QueryClient_Expecter) MarketMap(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_MarketMap_Call
MarketMap is a helper method to define mock.On call
- ctx context.Context
- in *types.MarketMapRequest
- opts ...grpc.CallOption
func (*QueryClient_Expecter) Markets ¶
func (_e *QueryClient_Expecter) Markets(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_Markets_Call
Markets is a helper method to define mock.On call
- ctx context.Context
- in *types.MarketsRequest
- opts ...grpc.CallOption
func (*QueryClient_Expecter) Params ¶
func (_e *QueryClient_Expecter) Params(ctx interface{}, in interface{}, opts ...interface{}) *QueryClient_Params_Call
Params is a helper method to define mock.On call
- ctx context.Context
- in *types.ParamsRequest
- opts ...grpc.CallOption
type QueryClient_LastUpdated_Call ¶
QueryClient_LastUpdated_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'LastUpdated'
func (*QueryClient_LastUpdated_Call) Return ¶
func (_c *QueryClient_LastUpdated_Call) Return(_a0 *types.LastUpdatedResponse, _a1 error) *QueryClient_LastUpdated_Call
func (*QueryClient_LastUpdated_Call) Run ¶
func (_c *QueryClient_LastUpdated_Call) Run(run func(ctx context.Context, in *types.LastUpdatedRequest, opts ...grpc.CallOption)) *QueryClient_LastUpdated_Call
func (*QueryClient_LastUpdated_Call) RunAndReturn ¶
func (_c *QueryClient_LastUpdated_Call) RunAndReturn(run func(context.Context, *types.LastUpdatedRequest, ...grpc.CallOption) (*types.LastUpdatedResponse, error)) *QueryClient_LastUpdated_Call
type QueryClient_MarketMap_Call ¶
QueryClient_MarketMap_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'MarketMap'
func (*QueryClient_MarketMap_Call) Return ¶
func (_c *QueryClient_MarketMap_Call) Return(_a0 *types.MarketMapResponse, _a1 error) *QueryClient_MarketMap_Call
func (*QueryClient_MarketMap_Call) Run ¶
func (_c *QueryClient_MarketMap_Call) Run(run func(ctx context.Context, in *types.MarketMapRequest, opts ...grpc.CallOption)) *QueryClient_MarketMap_Call
func (*QueryClient_MarketMap_Call) RunAndReturn ¶
func (_c *QueryClient_MarketMap_Call) RunAndReturn(run func(context.Context, *types.MarketMapRequest, ...grpc.CallOption) (*types.MarketMapResponse, error)) *QueryClient_MarketMap_Call
type QueryClient_Market_Call ¶
QueryClient_Market_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Market'
func (*QueryClient_Market_Call) Return ¶
func (_c *QueryClient_Market_Call) Return(_a0 *types.MarketResponse, _a1 error) *QueryClient_Market_Call
func (*QueryClient_Market_Call) Run ¶
func (_c *QueryClient_Market_Call) Run(run func(ctx context.Context, in *types.MarketRequest, opts ...grpc.CallOption)) *QueryClient_Market_Call
func (*QueryClient_Market_Call) RunAndReturn ¶
func (_c *QueryClient_Market_Call) RunAndReturn(run func(context.Context, *types.MarketRequest, ...grpc.CallOption) (*types.MarketResponse, error)) *QueryClient_Market_Call
type QueryClient_Markets_Call ¶
QueryClient_Markets_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Markets'
func (*QueryClient_Markets_Call) Return ¶
func (_c *QueryClient_Markets_Call) Return(_a0 *types.MarketsResponse, _a1 error) *QueryClient_Markets_Call
func (*QueryClient_Markets_Call) Run ¶
func (_c *QueryClient_Markets_Call) Run(run func(ctx context.Context, in *types.MarketsRequest, opts ...grpc.CallOption)) *QueryClient_Markets_Call
func (*QueryClient_Markets_Call) RunAndReturn ¶
func (_c *QueryClient_Markets_Call) RunAndReturn(run func(context.Context, *types.MarketsRequest, ...grpc.CallOption) (*types.MarketsResponse, error)) *QueryClient_Markets_Call
type QueryClient_Params_Call ¶
QueryClient_Params_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Params'
func (*QueryClient_Params_Call) Return ¶
func (_c *QueryClient_Params_Call) Return(_a0 *types.ParamsResponse, _a1 error) *QueryClient_Params_Call
func (*QueryClient_Params_Call) Run ¶
func (_c *QueryClient_Params_Call) Run(run func(ctx context.Context, in *types.ParamsRequest, opts ...grpc.CallOption)) *QueryClient_Params_Call
func (*QueryClient_Params_Call) RunAndReturn ¶
func (_c *QueryClient_Params_Call) RunAndReturn(run func(context.Context, *types.ParamsRequest, ...grpc.CallOption) (*types.ParamsResponse, error)) *QueryClient_Params_Call